#
# spec file for package krename
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define kf6_version 6.6.0
%define qt6_version 6.5.0

Name:           krename
Version:        5.0.2git.20250321T014623~262bdbe
Release:        1.1
Summary:        A batch renamer by KDE
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/krename
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libpodofo-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemViews) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(exiv2) >= 0.27
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(taglib)

%description
KRename is a powerful batch renamer for KDE. It allows you to easily rename
hundreds or even more files in one go. The filenames can be created by parts of
the original filename, numbering the files or accessing hundreds of informations
about the file, like creation date or Exif informations of an image.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name}

%files
%license LICENSES/*
%doc AUTHORS README.md
%{_kf6_applicationsdir}/org.kde.krename.desktop
%{_kf6_appstreamdir}/org.kde.krename.appdata.xml
%{_kf6_bindir}/krename
%{_kf6_iconsdir}/hicolor/*/apps/krename.png
%dir %{_kf6_sharedir}/kio/
%dir %{_kf6_sharedir}/kio/servicemenus/
%{_kf6_sharedir}/kio/servicemenus/krename_all_nonrec.desktop
%{_kf6_sharedir}/kio/servicemenus/krename_dir_rec.desktop

%files lang -f %{name}.lang

%changelog
* Tue Mar 25 2025 Christophe Marin <christophe@krop.fr>
- Switch to a git snapshot using Qt 6 / KF 6
- Drop patches:
  * servicemenus-files.patch
  * 0001-Support-podofo-0.10.patch
  * 0002-cmake-Improve-FindPoDoFo.patch
  * 0001-Fix-build-with-exiv2-0.28-raise-minimum-to-0.27.patch
  * remove-gplv2-code.diff
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Fri Aug  4 2023 Christophe Marin <christophe@krop.fr>
- Add patches:
  * 0001-Support-podofo-0.10.patch
  * 0002-cmake-Improve-FindPoDoFo.patch
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Add patch:
  * 0001-Fix-build-with-exiv2-0.28-raise-minimum-to-0.27.patch
* Tue Sep  6 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.0.2:
  * Prevent resizing issues with huge history entries (kde#398980)
  * cmake: stop shipping app icons as locolor
  * cmake: install 16px locolor icon as hicolor
  * Add additional information to Appstream metadata
  * Port away from deprecated KMessageBox::sorry
  * Use action terms instead of Yes/No buttons in dialogs
  * Remove the handbook entry leading into nowhere
  * Fix starting from app launcher on Wayland (kde#427207)
  * Updated translations (with newly included Estonian and Indonesian)
- Add signature file and keyring
* Sat Apr 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
* Tue Oct 20 2020 Christophe Giboudeaux <christophe@krop.fr>
- Make krename own the locolor icon directories.
  kf5-filesystem doesn't own these folders anymore.
* Tue Oct  6 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.0.1:
  * Escape/unescape filenames with special characters (kde#391291)
  * Close the app if the progress dialog is closed (kde#395084)
  * Fix building against exiv2-0.27
  * Fix build with taglib and ECM >= 5.72.0
  * Make icons look sharp with HiDPI (kde#418112)
- Drop patches merged upstream:
  * 0001-Use-cmakedefine01-instead-of-macro_bool_to_01.patch
  * 0002-Fix-building-against-exiv2-0.27.patch
  * 0003-Fix-the-previous-commits-and-the-build-with-exiv2-0..patch
  * use-local-cmake-modules-first.patch
  * Close-the-app-if-the-progress-dialog-is-closed.patch
- Drop lower-minimum-cmake-version.patch, Leap 42.3 is no longer
  supported
- Refresh servicemenus-files.patch
* Fri Oct  2 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Close-the-app-if-the-progress-dialog-is-closed.patch to fix
  krename not terminating after renaming (boo#1177221, kde#395084)
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Sat Jul 11 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add use-local-cmake-modules-first.patch to fix build with KDE
  Frameworks 5.72.0
- Remove no longer necessary workaround for podofo 0.9.5
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler words from description. Fix bumpy grammar in the
  sentence with filename composition.
* Wed Jan  2 2019 wbauer@tmo.at
- Add upstream patches to add support for exiv2-0.27:
  * 0001-Use-cmakedefine01-instead-of-macro_bool_to_01.patch
  * 0002-Fix-building-against-exiv2-0.27.patch
  * 0003-Fix-the-previous-commits-and-the-build-with-exiv2-0..patch
- Add lower-minimum-cmake-version.patch for Leap 42.3 to make it
  build with the older cmake version (3.5.2)
- Update servicemenus-files.patch and remove-gplv2-code.diff to
  conform to -p1 and use "%%autopatch -p1" to apply all patches
- Add missing Qt5Test build requirement
- Change URL to userbase.kde.org, krename.net is a bit outdated
- Run spec-cleaner
* Thu Feb 15 2018 wbauer@tmo.at
- Update to 5.0.0:
  * Ported to Qt5 and KDE Frameworks 5
- Drop no longer necessary patches:
  * gcc6-fix.patch
  * fix-freetype2-includes.patch
  * krename-4.0.7_add_common_names_to_FindLIBPODOFO.patch
  * desktop-files.diff
- Let %%suse_update_desktop_file add a GenericName instead of using
  a patch for that
* Fri Jun 17 2016 wbauer@tmo.at
- Add gcc6-fix.patch to fix build with gcc6 (boo#985366)
* Sun Mar  9 2014 tittiatcoke@gmail.com
- Add patch fix-freetype2-includes.patch to ensure that the right
  freetype2 includes are found
* Sat Nov 24 2012 alinm.elena@gmail.com
- added freetype2 dependency
* Mon May  7 2012 idonmez@suse.com
- Fix taglib requires for older distros
* Sun Apr 15 2012 dmueller@suse.com
- fix buildrequires (taglib->libtag)
* Wed Jan  4 2012 asterios.dramis@gmail.com
- Update to 4.0.9:
  * Fix for a compilation error in the PoDoFo plugin and updates the Czech
    translation.
  From 4.0.8:
  * Fix a crash on Ubuntu when starting KRename.
- Removed the patch to fix crash on static initialization (fixed upstream).
* Tue Aug 23 2011 dmueller@suse.de
- remove GPLv2 only code (only used for self-testing)
* Sat Aug 13 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed Group: to Productivity/File utilities.
  * Updates in Summary: and %%description sections.
  * Added update-desktop-files in Buildrequires:.
  * Removed support for openSUSE < 11.3.
  * Removed kde4-krename Provides/Obsoletes entries (not needed anymore).
  * Fixed rpmlint warning "file-contains-date-and-time".
  * Minor other updates.
- Modified the patch for krename.desktop to make the desktop file KDE and XDG
  compatible.
- Added a patch for the servicemenus to make them KDE and XDG compatible.
- Added a patch (taken from Fedora) to fix crash on static initialization.
- Added a patch (taken from upstream) to fix podofo library names cmake check.
* Mon Feb 21 2011 toddrme2178@gmail.com
- update to 4.0.7
  * Improved handling of directories
* Tue Feb  1 2011 toddrme2178@gmail.com
- update to 4.0.6
  * Translation updates
  * adds a list of recently-used tokens
* Tue Oct 19 2010 toddrme2178@gmail.com
- update to 4.0.5
  * adds advanced sorting modes
- add optional build-time dependency
  * libpodofo: provides pdf parsing capabilities
* Thu Jul  8 2010 beineri@opensuse.org
- update to 4.0.4
  * Translation updates
  * Some bugfixes
* Mon Feb  8 2010 coolo@novell.com
- update to 4.0.3
  * Translation updates
  * Some bugfixes
* Sun Dec  6 2009 tittiatcoke@gmail.com
- update to 4.0.2
  * Many bugfixes
* Sun Oct 11 2009 beineri@opensuse.org
- update to 4.0.1:
  * updates the German, Hungarian and Italian translation
  * the history of templates is now saved
* Thu Sep 24 2009 beineri@opensuse.org
- update to 4.0: first stable KDE4 release, updated translations
* Tue Jun  2 2009 beineri@opensuse.org
- reviewed changes
* Mon Jun  1 2009 tittiatcoke@gmail.com
- update to 3.9.3
  * countless bug fixes and fixes several crashes.
  * Contains most important features from the KDE3 version.
  * A new setting was introduced, so that KRename will ignore the file extension.
* Thu Oct  9 2008 dmueller@suse.de
- update to 3.9.2 (bnc#432364):
  * readds back missing desktop file and application icon
  * includes translations
* Mon Jul  7 2008 dmueller@suse.de
- update to 3.9.1:
  * 2nd beta release of the KDE4 based rewrite
* Mon Mar 26 2007 stbinner@suse.de
- update to 3.0.14:
  * Fixed a crash with plugin previews
  * Fixed adding directories recursive when dropped from another application
  * Added a unit test
  * Fixed plugin tokens with additional arguments e.g. [date;dd-mm-yyyy]
  * Fixed the seconds in the time [token]
  * Corrected documentation of [user] and [group] tokens
  * Patch by Otakar Trunecek to add Czech transliteration characters
* Mon Dec  4 2006 stbinner@suse.de
- update to 3.0.13:
  * new Turkish translation
  * the encoding plugin is now finally working
  * the speed with plugins could be improved
  * commandline option to specify the number of preview items to show
* Tue Aug 15 2006 dmueller@suse.de
- update to 3.0.12:
  * Updated translation
  * Fixed servicemenu installation
  * Fixed a possible crash
  * Fixed drag and drop of files to KRename
* Wed May 24 2006 adrian@suse.de
- fix build for < 10.1
* Thu Feb 23 2006 stbinner@suse.de
- update to 3.0.11
  * cleans up all makefiles and desktop files
  * updates the build system to the build system of KDE 3.5
  * updates some translations (Swedish and Italian)
  * fixes a bug when *,{ or } was returned by plugins
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 dmueller@suse.de
- spec file cleanup
* Wed Jan 11 2006 stbinner@suse.de
- update to 3.0.10
* Tue Oct 18 2005 stbinner@suse.de
- update to 3.0.9
* Sun Sep 25 2005 stbinner@suse.de
- update to 3.0.8
* Mon Sep 19 2005 stbinner@suse.de
- update to 3.0.7
* Tue Jun 21 2005 dmueller@suse.de
- update to 3.0.6
* Thu Feb 17 2005 adrian@suse.de
- update to version 3.0.3
- menu entry moved to xdg dir
* Thu Oct 14 2004 coolo@suse.de
- update to version 3.0.2
* Mon Feb  2 2004 adrian@suse.de
- update to version 2.8.5
* Wed Jan 14 2004 coolo@suse.de
- fixing build
* Wed Jan 14 2004 coolo@suse.de
- fixing Makefile problems
* Fri Dec  5 2003 adrian@suse.de
- update to version 2.8.4
* Tue Oct 28 2003 adrian@suse.de
- update to version 2.8.3
* Tue Sep  9 2003 adrian@suse.de
- add hungarian translations from Peter Varkoly
* Fri Aug  8 2003 adrian@suse.de
- update to version 2.8.2
* Sun Jul 27 2003 adrian@suse.de
- update to version 2.8.1
- add Categories
* Sat Jun 14 2003 coolo@suse.de
- use %%find_lang
* Sun May 18 2003 adrian@suse.de
- update to version 2.7.1
* Wed May 14 2003 adrian@suse.de
- initial package of version 2.6.2
